@@ -1,4 +1,4 @@
-/* $Id: readpix.c,v 1.4.2.1 2002/05/01 14:53:52 alanh Exp $ */
+/* $Id: readpix.c,v 1.8 2002/07/12 15:54:02 brianp Exp $ */
 
 /*
  * glReadPixels and glCopyPixels test
@@ -6,30 +6,6 @@
  * Brian Paul   March 1, 2000  This file is in the public domain.
  */
 
-/*
- * $Log: readpix.c,v $
- * Revision 1.4.2.1  2002/05/01 14:53:52  alanh
- * glutSwapBuffers implicitly does a glFinish when swapping back to the front
- * buffer. We now issue a glFinish when not issuing SwapBuffers to ensure
- * the pipeline is complete.
- *
- * (Problem found with Chromium).
- *
- * Revision 1.4  2000/10/16 21:24:39  brianp
- * use gray background, memset TempImage to white to help with debugging
- *
- * Revision 1.3  2000/03/31 01:01:31  brianp
- * tweaks to allow different read formats/types
- *
- * Revision 1.2  2000/03/23 19:47:25  brianp
- * added benchmarking
- *
- * Revision 1.1  2000/03/01 16:23:14  brianp
- * test glDraw/Read/CopyPixels()
- *
- */
-
-
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -243,7 +219,7 @@ Init( GLboolean ciMode )
 
    if (ciMode) {
       /* Convert RGB image to grayscale */
-      GLubyte *indexImage = malloc( ImgWidth * ImgHeight );
+      GLubyte *indexImage = (GLubyte *) malloc( ImgWidth * ImgHeight );
       GLint i;
       for (i=0; i<ImgWidth*ImgHeight; i++) {
          int gray = Image[i*3] + Image[i*3+1] + Image[i*3+2];
